==> istio-model-v1beta1-6.5.0-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicySpecFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluent;

 /**
  * Generated
  */
public interface AuthorizationPolicySpecFluent<A extends AuthorizationPolicySpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildActionDetail instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsAuthorizationPolicyActionDetail getActionDetail();
  public IsAuthorizationPolicyActionDetail buildActionDetail();
  public A withActionDetail(IsAuthorizationPolicyActionDetail actionDetail);
  public Boolean hasActionDetail();
  public A withAuthorizationPolicyProviderActionDetail(AuthorizationPolicyProvider authorizationPolicyProviderActionDetail);
  public AuthorizationPolicySpecFluent.AuthorizationPolicyProviderActionDetailNested<A> withNewAuthorizationPolicyProviderActionDetail();
  public AuthorizationPolicySpecFluent.AuthorizationPolicyProviderActionDetailNested<A> withNewAuthorizationPolicyProviderActionDetailLike(AuthorizationPolicyProvider item);
  public AuthorizationPolicyAction getAction();
  public A withAction(AuthorizationPolicyAction action);
  public Boolean hasAction();
  public A addToRules(Integer index,Rule item);
  public A setToRules(Integer index,Rule item);
  public A addToRules(io.fabric8.istio.api.security.v1beta1.Rule... items);
  public A addAllToRules(Collection<Rule> items);
  public A removeFromRules(io.fabric8.istio.api.security.v1beta1.Rule... items);
  public A removeAllFromRules(Collection<Rule> items);
  public A removeMatchingFromRules(Predicate<RuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Rule> getRules();
  public List<Rule> buildRules();
  public Rule buildRule(Integer index);
  public Rule buildFirstRule();
  public Rule buildLastRule();
  public Rule buildMatchingRule(Predicate<RuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<RuleBuilder> predicate);
  public A withRules(List<Rule> rules);
  public A withRules(io.fabric8.istio.api.security.v1beta1.Rule... rules);
  public Boolean hasRules();
  public AuthorizationPolicySpecFluent.RulesNested<A> addNewRule();
  public AuthorizationPolicySpecFluent.RulesNested<A> addNewRuleLike(Rule item);
  public AuthorizationPolicySpecFluent.RulesNested<A> setNewRuleLike(Integer index,Rule item);
  public AuthorizationPolicySpecFluent.RulesNested<A> editRule(Integer index);
  public AuthorizationPolicySpecFluent.RulesNested<A> editFirstRule();
  public AuthorizationPolicySpecFluent.RulesNested<A> editLastRule();
  public AuthorizationPolicySpecFluent.RulesNested<A> editMatchingRule(Predicate<RuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector();
  public WorkloadSelector buildSelector();
  public A withSelector(WorkloadSelector selector);
  public Boolean hasSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> withNewTypeSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item);
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> editTypeSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> editOrNewSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item);
  public interface AuthorizationPolicyProviderActionDetailNested<N> extends Nested<N>,AuthorizationPolicyProviderFluent<AuthorizationPolicySpecFluent.AuthorizationPolicyProviderActionDetailNested<N>>{
    public N and();
    public N endAuthorizationPolicyProviderActionDetail();
    
  }
  public interface RulesNested<N> extends Nested<N>,RuleFluent<AuthorizationPolicySpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  public interface TypeSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<AuthorizationPolicySpecFluent.TypeSelectorNested<N>>{
    public N and();
    public N endTypeSelector();
    
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicySpecFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluent;

 /**
  * Generated
  */
public interface AuthorizationPolicySpecFluent<A extends AuthorizationPolicySpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildActionDetail instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsAuthorizationPolicyActionDetail getActionDetail();
  public IsAuthorizationPolicyActionDetail buildActionDetail();
  public A withActionDetail(IsAuthorizationPolicyActionDetail actionDetail);
  public Boolean hasActionDetail();
  public A withAuthorizationPolicyProviderActionDetail(AuthorizationPolicyProvider authorizationPolicyProviderActionDetail);
  public AuthorizationPolicySpecFluent.AuthorizationPolicyProviderActionDetailNested<A> withNewAuthorizationPolicyProviderActionDetail();
  public AuthorizationPolicySpecFluent.AuthorizationPolicyProviderActionDetailNested<A> withNewAuthorizationPolicyProviderActionDetailLike(AuthorizationPolicyProvider item);
  public AuthorizationPolicyAction getAction();
  public A withAction(AuthorizationPolicyAction action);
  public Boolean hasAction();
  public A addToRules(int index,Rule item);
  public A setToRules(int index,Rule item);
  public A addToRules(io.fabric8.istio.api.security.v1beta1.Rule... items);
  public A addAllToRules(Collection<Rule> items);
  public A removeFromRules(io.fabric8.istio.api.security.v1beta1.Rule... items);
  public A removeAllFromRules(Collection<Rule> items);
  public A removeMatchingFromRules(Predicate<RuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Rule> getRules();
  public List<Rule> buildRules();
  public Rule buildRule(int index);
  public Rule buildFirstRule();
  public Rule buildLastRule();
  public Rule buildMatchingRule(Predicate<RuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<RuleBuilder> predicate);
  public A withRules(List<Rule> rules);
  public A withRules(io.fabric8.istio.api.security.v1beta1.Rule... rules);
  public Boolean hasRules();
  public AuthorizationPolicySpecFluent.RulesNested<A> addNewRule();
  public AuthorizationPolicySpecFluent.RulesNested<A> addNewRuleLike(Rule item);
  public AuthorizationPolicySpecFluent.RulesNested<A> setNewRuleLike(int index,Rule item);
  public AuthorizationPolicySpecFluent.RulesNested<A> editRule(int index);
  public AuthorizationPolicySpecFluent.RulesNested<A> editFirstRule();
  public AuthorizationPolicySpecFluent.RulesNested<A> editLastRule();
  public AuthorizationPolicySpecFluent.RulesNested<A> editMatchingRule(Predicate<RuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector();
  public WorkloadSelector buildSelector();
  public A withSelector(WorkloadSelector selector);
  public Boolean hasSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> withNewTypeSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item);
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> editTypeSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> editOrNewSelector();
  public AuthorizationPolicySpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item);
  public interface AuthorizationPolicyProviderActionDetailNested<N> extends Nested<N>,AuthorizationPolicyProviderFluent<AuthorizationPolicySpecFluent.AuthorizationPolicyProviderActionDetailNested<N>>{
    public N and();
    public N endAuthorizationPolicyProviderActionDetail();
    
  }
  public interface RulesNested<N> extends Nested<N>,RuleFluent<AuthorizationPolicySpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  public interface TypeSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<AuthorizationPolicySpecFluent.TypeSelectorNested<N>>{
    public N and();
    public N endTypeSelector();
    
  }
  
}
